#ifndef NT2_INCLUDE_FUNCTIONS_LE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LE_HPP_INCLUDED

#include <nt2/operator/include/functions/le.hpp>

#endif
